.. _elhaz-config-list:

``elhaz config list``
=====================

Synopsis
--------

.. code-block:: text

   elhaz config list

Description
-----------

Print the names of all configs in the local config store, one per line, in
alphabetical order.

Options
-------

``--help``
   Show help message and exit.

Examples
--------

.. code-block:: bash

   elhaz config list
